@@ -9,7 +9,7 @@ def main():
     manager = SetupManager()
     manager.load_config()
     manager.connect_to_game()
-    manager.launch_quick_chat_manager()
+    manager.launch_early_start_bot_processes()
     manager.start_match()
     manager.launch_bot_processes()
     manager.infinite_loop()  # Runs forever until interrupted
