@@ -407,7 +407,7 @@ class SetupManager:
                                            self.teams[i], participant_index, self.python_files[i], self.agent_metadata_queue,
                                            self.match_config, self.matchcomms_server.root_url, spawn_id))
                 process.start()
-                self.bot_processes[i] = process
+                self.bot_processes[participant_index] = process
                 num_started += 1
 
         self.logger.debug(f"Successfully started {num_started} bot processes")
